#!/usr/bin/env bash
#
# Copyright 2016 - The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

set -e

TOOLS_DIR=$(realpath $(dirname $0))
TOOLS_DUMP_DIR=$TOOLS_DIR/dump
LTP_ANDROID_DIR=$(realpath $TOOLS_DIR/..)
LTP_ROOT=$(realpath $LTP_ANDROID_DIR/..)
CUSTOM_CFLAGS_PATH=$TOOLS_DIR/custom_cflags.json
OUTPUT_MK=$LTP_ANDROID_DIR/Android.ltp.mk
OUTPUT_PLIST=$LTP_ANDROID_DIR/ltp_package_list.mk
OUTPUT_BP=$LTP_ROOT/gen.bp

export PYTHONDONTWRITEBYTECODE=1

cd $TOOLS_DIR

case $1 in
  -u|--update)
    echo "Update option enabled. Regenerating..."
    rm -rf *.dump
    ;;
  -h|--help)
    echo "Generate Android.ltp.mk / gen.bp."
    echo "Please use \"--update\" option to update and regenerate Android.ltp.mk / gen.bp."
    exit 0
    ;;
esac

if ! [ -f $TOOLS_DUMP_DIR/make_dry_run.dump ]; then
  DOCKER_USERNAME=$(id -un)
  DOCKER_UID=$(id -u)
  DOCKER_GID=$(id -g)

  echo "LTP make dry_run not dumped. Dumping..."
  echo ""
  echo "This may need your sudo password in order to access docker:"
  set -x
  sudo docker build --build-arg userid=$DOCKER_UID --build-arg groupid=$DOCKER_GID --build-arg username=$DOCKER_USERNAME --build-arg ltproot=$LTP_ROOT -t android-gen-ltp .
  sudo docker run -it --rm -v $LTP_ROOT:/src -w /src/android/tools android-gen-ltp
  set +x
fi

cat $LTP_ANDROID_DIR/AOSP_license_text.txt > $OUTPUT_MK
echo "" >> $OUTPUT_MK
echo "# This file is autogenerated by $(basename $0)" >> $OUTPUT_MK
echo "" >> $OUTPUT_MK

cat $LTP_ANDROID_DIR/AOSP_license_text.txt > $OUTPUT_PLIST
echo "" >> $OUTPUT_PLIST
echo "# This file is autogenerated by $(basename $0)" >> $OUTPUT_PLIST
echo "" >> $OUTPUT_PLIST

sed "s%#%//%" $LTP_ANDROID_DIR/AOSP_license_text.txt > $OUTPUT_BP
echo "" >> $OUTPUT_BP
echo "// This file is autogenerated by $(basename $0)" >> $OUTPUT_BP
echo "" >> $OUTPUT_BP

echo ""
echo "Parsing LTP make dry_run output..."
CMD="python android_build_generator.py --ltp_root $LTP_ROOT --output_mk_path $OUTPUT_MK \
    --output_bp_path $OUTPUT_BP --output_plist_path $OUTPUT_PLIST \
    --custom_cflags_file $CUSTOM_CFLAGS_PATH"
echo $CMD
$CMD
